==> zio-aws-rds_3-5.17.128.1-sources.jar: zio/aws/rds/model/DescribeDbProxyEndpointsRequest.scala <==
package zio.aws.rds.model
import java.lang.Integer
import zio.aws.rds.model.primitives.{
  MaxRecords,
  DBProxyEndpointName,
  DBProxyName
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DescribeDbProxyEndpointsRequest(
    dbProxyName: scala.Option[DBProxyName] = None,
    dbProxyEndpointName: scala.Option[DBProxyEndpointName] = None,
    filters: scala.Option[Iterable[zio.aws.rds.model.Filter]] = None,
    marker: scala.Option[String] = None,
    maxRecords: scala.Option[MaxRecords] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.DescribeDbProxyEndpointsRequest = {
    import DescribeDbProxyEndpointsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.DescribeDbProxyEndpointsRequest
      .builder()
      .optionallyWith(
        dbProxyName.map(value => DBProxyName.unwrap(value): java.lang.String)
      )(_.dbProxyName)
      .optionallyWith(
        dbProxyEndpointName.map(value =>
          DBProxyEndpointName.unwrap(value): java.lang.String
        )
      )(_.dbProxyEndpointName)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .optionallyWith(
        maxRecords.map(value => MaxRecords.unwrap(value): Integer)
      )(_.maxRecords)
      .build()
  }
  def asReadOnly: zio.aws.rds.model.DescribeDbProxyEndpointsRequest.ReadOnly =
    zio.aws.rds.model.DescribeDbProxyEndpointsRequest.wrap(buildAwsValue())
}
object DescribeDbProxyEndpointsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.DescribeDbProxyEndpointsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.DescribeDbProxyEndpointsRequest =
      zio.aws.rds.model.DescribeDbProxyEndpointsRequest(
        dbProxyName.map(value => value),
        dbProxyEndpointName.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        marker.map(value => value),
        maxRecords.map(value => value)
      )
    def dbProxyName: scala.Option[DBProxyName]
    def dbProxyEndpointName: scala.Option[DBProxyEndpointName]
    def filters: scala.Option[List[zio.aws.rds.model.Filter.ReadOnly]]
    def marker: scala.Option[String]
    def maxRecords: scala.Option[MaxRecords]
    def getDbProxyName: ZIO[Any, AwsError, DBProxyName] =
      AwsError.unwrapOptionField("dbProxyName", dbProxyName)
    def getDbProxyEndpointName: ZIO[Any, AwsError, DBProxyEndpointName] =
      AwsError.unwrapOptionField("dbProxyEndpointName", dbProxyEndpointName)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.rds.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
    def getMaxRecords: ZIO[Any, AwsError, MaxRecords] =
      AwsError.unwrapOptionField("maxRecords", maxRecords)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.DescribeDbProxyEndpointsRequest
  ) extends zio.aws.rds.model.DescribeDbProxyEndpointsRequest.ReadOnly {
    override val dbProxyName: scala.Option[DBProxyName] = scala
      .Option(impl.dbProxyName())
      .map(value => zio.aws.rds.model.primitives.DBProxyName(value))
    override val dbProxyEndpointName: scala.Option[DBProxyEndpointName] = scala
      .Option(impl.dbProxyEndpointName())
      .map(value => zio.aws.rds.model.primitives.DBProxyEndpointName(value))
    override val filters
        : scala.Option[List[zio.aws.rds.model.Filter.ReadOnly]] = scala
      .Option(impl.filters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.rds.model.Filter.wrap(item)
        }.toList
      )
    override val marker: scala.Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
    override val maxRecords: scala.Option[MaxRecords] = scala
      .Option(impl.maxRecords())
      .map(value => zio.aws.rds.model.primitives.MaxRecords(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.DescribeDbProxyEndpointsRequest
  ): zio.aws.rds.model.DescribeDbProxyEndpointsRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-rds_3-5.17.196.1-sources.jar: zio/aws/rds/model/DescribeDbProxyEndpointsRequest.scala <==
package zio.aws.rds.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.rds.model.primitives.{
  MaxRecords,
  DBProxyEndpointName,
  DBProxyName
}
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class DescribeDbProxyEndpointsRequest(
    dbProxyName: Optional[DBProxyName] = Optional.Absent,
    dbProxyEndpointName: Optional[DBProxyEndpointName] = Optional.Absent,
    filters: Optional[Iterable[zio.aws.rds.model.Filter]] = Optional.Absent,
    marker: Optional[String] = Optional.Absent,
    maxRecords: Optional[MaxRecords] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.DescribeDbProxyEndpointsRequest = {
    import DescribeDbProxyEndpointsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.DescribeDbProxyEndpointsRequest
      .builder()
      .optionallyWith(
        dbProxyName.map(value => DBProxyName.unwrap(value): java.lang.String)
      )(_.dbProxyName)
      .optionallyWith(
        dbProxyEndpointName.map(value =>
          DBProxyEndpointName.unwrap(value): java.lang.String
        )
      )(_.dbProxyEndpointName)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .optionallyWith(
        maxRecords.map(value => MaxRecords.unwrap(value): Integer)
      )(_.maxRecords)
      .build()
  }
  def asReadOnly: zio.aws.rds.model.DescribeDbProxyEndpointsRequest.ReadOnly =
    zio.aws.rds.model.DescribeDbProxyEndpointsRequest.wrap(buildAwsValue())
}
object DescribeDbProxyEndpointsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.DescribeDbProxyEndpointsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.DescribeDbProxyEndpointsRequest =
      zio.aws.rds.model.DescribeDbProxyEndpointsRequest(
        dbProxyName.map(value => value),
        dbProxyEndpointName.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        marker.map(value => value),
        maxRecords.map(value => value)
      )
    def dbProxyName: Optional[DBProxyName]
    def dbProxyEndpointName: Optional[DBProxyEndpointName]
    def filters: Optional[List[zio.aws.rds.model.Filter.ReadOnly]]
    def marker: Optional[String]
    def maxRecords: Optional[MaxRecords]
    def getDbProxyName: ZIO[Any, AwsError, DBProxyName] =
      AwsError.unwrapOptionField("dbProxyName", dbProxyName)
    def getDbProxyEndpointName: ZIO[Any, AwsError, DBProxyEndpointName] =
      AwsError.unwrapOptionField("dbProxyEndpointName", dbProxyEndpointName)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.rds.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
    def getMaxRecords: ZIO[Any, AwsError, MaxRecords] =
      AwsError.unwrapOptionField("maxRecords", maxRecords)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.DescribeDbProxyEndpointsRequest
  ) extends zio.aws.rds.model.DescribeDbProxyEndpointsRequest.ReadOnly {
    override val dbProxyName: Optional[DBProxyName] = zio.aws.core.internal
      .optionalFromNullable(impl.dbProxyName())
      .map(value => zio.aws.rds.model.primitives.DBProxyName(value))
    override val dbProxyEndpointName: Optional[DBProxyEndpointName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dbProxyEndpointName())
        .map(value => zio.aws.rds.model.primitives.DBProxyEndpointName(value))
    override val filters: Optional[List[zio.aws.rds.model.Filter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.rds.model.Filter.wrap(item)
          }.toList
        )
    override val marker: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => value: String)
    override val maxRecords: Optional[MaxRecords] = zio.aws.core.internal
      .optionalFromNullable(impl.maxRecords())
      .map(value => zio.aws.rds.model.primitives.MaxRecords(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.DescribeDbProxyEndpointsRequest
  ): zio.aws.rds.model.DescribeDbProxyEndpointsRequest.ReadOnly = new Wrapper(
    impl
  )
}
